==> japhar-0.08.tar.gz: japhar-0.08/lib/libruntime/printf.c <==
/* -*- Mode: C; c-file-style: "gnu" -*-
   printf.c -- our own version of printf/fprintf that calls the vm hook.
   Created: Chris Toshok <toshok@hungry.com>, 15-Aug-1997
*/
/*
  This file is part of Japhar, the GNU Virtual Machine for Java Bytecodes.
  Japhar is a project of The Hungry Programmers, GNU, and OryxSoft.

  Copyright (C) 1997, 1998, 1999 The Hungry Programmers

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
#include "jniint.h"
#include "native-threads.h"

#include <stdarg.h>
#include <stdio.h>

int
printf (const char *format,
	...)
{
  JNIEnv *env = THREAD_getEnv();
  va_list args;
  int result;

  va_start(args, format);

  if (env)
    {
      HungryJNIEnv *henv = (HungryJNIEnv*)env;
      if (henv->_vm
	  && henv->_vm->vfprintf)
	result = (*henv->_vm->vfprintf)(stdout, format, args);
      else
	result = vfprintf(stdout, format, args);
    }
  else
    result = vfprintf(stdout, format, args);

  va_end(args);

  return result;
}

int
fprintf (FILE *fp,
	 const char *format,
	 ...)
{
  JNIEnv *env = THREAD_getEnv();
  va_list args;
  int result;

  va_start(args, format);

  if (env)
    {
      HungryJNIEnv *henv = (HungryJNIEnv*)env;
      if (henv->_vm
	  && henv->_vm->vfprintf)
	result = (*henv->_vm->vfprintf)(fp, format, args);
      else
	result = vfprintf(fp, format, args);
    }
  else
    result = vfprintf(fp, format, args);

  va_end(args);

  return result;
}

==> japhar-0.11.tar.gz: japhar-0.11/lib/libruntime/printf.c <==
/* -*- Mode: C; c-file-style: "gnu"; indent-tabs-mode:nil -*-
   printf.c -- our own version of printf/fprintf that calls the vm hook.
   Created: Chris Toshok <toshok@hungry.com>, 15-Aug-1997
*/
/*
  This file is part of Japhar, the GNU Virtual Machine for Java Bytecodes.
  Japhar is a project of The Hungry Programmers, GNU, and OryxSoft.

  Copyright (C) 1997, 1998, 1999 The Hungry Programmers

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
#include "runtimeint.h"
#include "arch.h"

#include <stdarg.h>
#include <stdio.h>

int
printf (const char *format,
        ...)
{
  HungryEnv *henv = HVM_ThreadGetEnv();
  va_list args;
  int result;

  va_start(args, format);

  if (henv)
    {
      if (henv->vm->vfprintf)
        result = henv->vm->vfprintf(stdout, format, args);
      else
        result = vfprintf(stdout, format, args);
    }
  else
    result = vfprintf(stdout, format, args);

  va_end(args);

  return result;
}

int
fprintf (FILE *fp,
         const char *format,
         ...)
{
  HungryEnv *henv = HVM_ThreadGetEnv();
  va_list args;
  int result;

  va_start(args, format);

  if (henv)
    {
      if (henv->vm->vfprintf)
        result = henv->vm->vfprintf(fp, format, args);
      else
        result = vfprintf(fp, format, args);
    }
  else
    result = vfprintf(fp, format, args);

  va_end(args);

  return result;
}
